@@ -1,5 +1,3 @@
-/* $Id: netlist.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* This file is part of LibGTop 2.0.
 
    LibGTop is free software; you can redistribute it and/or modify it
@@ -27,7 +25,7 @@ static const unsigned long _glibtop_sysdeps_netlist = 0;
 /* Init function. */
 
 void
-glibtop_init_netlist_s (glibtop *server)
+_glibtop_init_netlist_s (glibtop *server)
 {
 	server->sysdeps.netlist = _glibtop_sysdeps_netlist;
 }
