@@ -1,5 +1,3 @@
-/* $Id: procstate.c,v 1.15 2005/12/12 09:38:14 jamesh Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -30,7 +28,7 @@ static const unsigned long _glibtop_sysdeps_proc_state = 0;
 /* Init function. */
 
 void
-glibtop_init_proc_state_s (glibtop *server)
+_glibtop_init_proc_state_s (glibtop *server)
 {
 	server->sysdeps.proc_state = _glibtop_sysdeps_proc_state;
 }
